@@ -34,7 +34,7 @@
 #' * `success`: A boolean value indicating if the operation was apparently
 #' successful.
 #' * `status_code`: The
-#' [http status code](http://en.wikipedia.org/wiki/List_of_HTTP_status_codes)
+#' [http status code](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes)
 #' of the operation.
 #' * `outcome_message`: A human readable string indicating the operation's
 #' outcome.
@@ -142,11 +142,11 @@ redcap_download_file_oneshot <- function(
   if (0L < nchar(event)) post_body$event <- event
 
   if (!is.null(repeat_instrument)) {
-      if (is.null(repeat_instance)) {
-          stop("You must specify repeat_instance when specified repeat_instrement");
-      }
-      post_body$repeat_instrument <- repeat_instrument
-      post_body$repeat_instance   <- repeat_instance
+    if (is.null(repeat_instance)) {
+      stop("You must specify repeat_instance when specified repeat_instrement")
+    }
+    post_body$repeat_instrument <- repeat_instrument
+    post_body$repeat_instance   <- repeat_instance
   }
 
   # This is the first of two important lines in the function.
