@@ -48,7 +48,9 @@
 #  placeholder: returnFormat
 #' @param export_survey_fields A boolean that specifies whether to export the
 #' survey identifier field (e.g., 'redcap_survey_identifier') or survey
-#' timestamp fields (e.g., instrument+'_timestamp') .
+#' timestamp fields (e.g., instrument+'_timestamp').
+#' The timestamp outputs reflect the survey's *completion* time
+#' (according to the time and timezone of the REDCap server.)
 #' @param export_data_access_groups A boolean value that specifies whether or
 #' not to export the `redcap_data_access_group` field when data access groups
 #' are utilized in the project. Default is `FALSE`. See the details below.
@@ -56,6 +58,16 @@
 #' filtering the data to be returned by this API method, in which the API
 #' will only return the records (or record-events, if a longitudinal project)
 #' where the logic evaluates as TRUE.   An blank/empty string returns all records.
+#' @param datetime_range_begin To return only records that have been created or
+#' modified *after* a given datetime, provide a
+#' [POSIXct](https://stat.ethz.ch/R-manual/R-devel/library/base/html/as.POSIXlt.html)
+#' value.
+#' If not specified, REDCap will assume no begin time.
+#' @param datetime_range_end To return only records that have been created or
+#' modified *before* a given datetime, provide a
+#' [POSIXct](https://stat.ethz.ch/R-manual/R-devel/library/base/html/as.POSIXlt.html)
+#' value.
+#' If not specified, REDCap will assume no end time.
 #' @param col_types A [readr::cols()] object passed internally to
 #' [readr::read_csv()].  Optional.
 #' @param guess_type A boolean value indicating if all columns should be
@@ -77,7 +89,7 @@
 #' * `success`: A boolean value indicating if the operation was apparently
 #' successful.
 #' * `status_codes`: A collection of
-#' [http status codes](http://en.wikipedia.org/wiki/List_of_HTTP_status_codes),
+#' [http status codes](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes),
 #' separated by semicolons.  There is one code for each batch attempted.
 #' * `outcome_messages`: A collection of human readable strings indicating the
 #' operations' semicolons.  There is one code for each batch attempted.  In an
@@ -90,7 +102,7 @@
 #' * `elapsed_seconds`: The duration of the function.
 #'
 #' @details
-#' Specifically, it internally uses multiple calls to [redcap_read_oneshot()]
+#' [redcap_read()] internally uses multiple calls to [redcap_read_oneshot()]
 #' to select and return data.  Initially, only the primary key is queried
 #' through the REDCap API.  The long list is then subsetted into batches,
 #' whose sizes are determined by the `batch_size` parameter.  REDCap is then
@@ -105,7 +117,7 @@
 #' A second benefit is less RAM is required on the webserver.  Because
 #' each batch is smaller than the entire dataset, the webserver
 #' tackles more manageably sized objects in memory.  Consider batching
-#' if you encounter the error
+#' if you encounter the error:
 #'
 #' ```
 #' ERROR: REDCap ran out of server memory. The request cannot be processed.
@@ -172,6 +184,8 @@ redcap_read <- function(
   export_survey_fields          = FALSE,
   export_data_access_groups     = FALSE,
   filter_logic                  = "",
+  datetime_range_begin          = as.POSIXct(NA),
+  datetime_range_end            = as.POSIXct(NA),
 
   col_types                     = NULL,
   guess_type                    = TRUE,
@@ -199,12 +213,14 @@ redcap_read <- function(
   # placeholder: returnFormat
   checkmate::assert_logical(  export_survey_fields      , any.missing=FALSE,     len=1)
   checkmate::assert_logical(  export_data_access_groups , any.missing=FALSE,     len=1)
-  #
+  checkmate::assert_posixct(  datetime_range_begin      , any.missing=TRUE , len=1, null.ok=TRUE)
+  checkmate::assert_posixct(  datetime_range_end        , any.missing=TRUE , len=1, null.ok=TRUE)
+
   checkmate::assert_logical(  guess_type                , any.missing=FALSE,     len=1)
 
   if (!is.null(guess_max)) warning("The `guess_max` parameter in `REDCapR::redcap_read()` is deprecated.")
   checkmate::assert_logical(  verbose                   , any.missing=FALSE,     len=1, null.ok=TRUE)
-  checkmate::assert_list(     config_options            , any.missing=TRUE ,     len=1, null.ok=TRUE)
+  checkmate::assert_list(     config_options            , any.missing=TRUE ,            null.ok=TRUE)
   checkmate::assert_integer(  id_position               , any.missing=FALSE,     len=1, lower=1L)
 
   validate_field_names(fields, stop_on_error = TRUE)
@@ -245,6 +261,8 @@ redcap_read <- function(
     forms_collapsed    = forms_collapsed,
     events_collapsed   = events_collapsed,
     filter_logic       = filter_logic,
+    datetime_range_begin   = datetime_range_begin,
+    datetime_range_end     = datetime_range_end,
     guess_type         = guess_type,
     verbose            = verbose,
     config_options     = config_options
@@ -261,6 +279,8 @@ redcap_read <- function(
       forms_collapsed       = "failed in initial batch call",
       events_collapsed      = "failed in initial batch call",
       filter_logic          = "failed in initial batch call",
+      datetime_range_begin  = "failed in initial batch call",
+      datetime_range_end    = "failed in initial batch call",
       elapsed_seconds       = elapsed_seconds,
       status_code           = initial_call$status_code,
       outcome_messages      = outcome_messages,
@@ -308,6 +328,8 @@ redcap_read <- function(
       export_survey_fields        = export_survey_fields,
       export_data_access_groups   = export_data_access_groups,
       filter_logic                = filter_logic,
+      datetime_range_begin        = datetime_range_begin,
+      datetime_range_end          = datetime_range_end,
 
       col_types                   = col_types,
       guess_type                  = FALSE,
@@ -340,7 +362,7 @@ redcap_read <- function(
     }
 
     lst_batch[[i]]   <- read_result$data
-    success_combined <- success_combined | read_result$success
+    success_combined <- success_combined & read_result$success
 
     rm(read_result) #Admittedly overkill defensiveness.
   }
@@ -368,6 +390,9 @@ redcap_read <- function(
     forms_collapsed     = forms_collapsed,
     events_collapsed    = events_collapsed,
     filter_logic        = filter_logic,
+    datetime_range_begin= datetime_range_begin,
+    datetime_range_end  = datetime_range_end,
+
     elapsed_seconds     = elapsed_seconds
   )
 }
