@@ -15,6 +15,17 @@
 #' project.  Required.
 #' @param token The user-specific string that serves as the password for a
 #' project.  Required.
+#' @param overwrite_with_blanks A boolean value indicating if
+#' blank/`NA` values in the R [base::data.frame]
+#' will overwrite data on the server.
+#' This is the default behavior for REDCapR,
+#' which essentially deletes the cell's value
+#' If `FALSE`, blank/`NA` values in the [base::data.frame]
+#' will be ignored.  Optional.
+#' @param convert_logical_to_integer If `TRUE`, all [base::logical] columns
+#' in `ds` are cast to an integer before uploading to REDCap.
+#' Boolean values are typically represented as 0/1 in REDCap radio buttons.
+#' Optional.
 #' @param verbose A boolean value indicating if `message`s should be printed
 #' to the R console during the operation.  The verbose output might contain
 #' sensitive information (*e.g.* PHI), so turn this off if the output might
@@ -26,7 +37,7 @@
 #' * `success`: A boolean value indicating if the operation was apparently
 #' successful.
 #' * `status_code`: The
-#' [http status code](http://en.wikipedia.org/wiki/List_of_HTTP_status_codes)
+#' [http status code](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes)
 #' of the operation.
 #' * `outcome_message`: A human readable string indicating the operation's
 #' outcome.
@@ -73,7 +84,7 @@
 #'
 #' ds1 <- ds1[1:3, ]
 #' ds1$age       <- NULL; ds1$bmi <- NULL #Drop the calculated fields before writing.
-#' result_write  <- REDCapR::redcap_write(ds=ds1, redcap_uri=uri, token=token)
+#' result_write  <- REDCapR::redcap_write(ds1, redcap_uri=uri, token=token)
 #'
 #' # Read the dataset for the second time.
 #' result_read2  <- REDCapR::redcap_read_oneshot(redcap_uri=uri, token=token)
@@ -84,7 +95,7 @@
 #' ds1$telephone <- paste0("(405) 321-000", seq_len(nrow(ds1)))
 #'
 #' # This next line will throw an error.
-#' result_write <- REDCapR::redcap_write(ds=ds1, redcap_uri=uri, token=token)
+#' result_write <- REDCapR::redcap_write(ds1, redcap_uri=uri, token=token)
 #' result_write$raw_text
 #' }
 
@@ -96,6 +107,8 @@ redcap_write <- function(
   continue_on_error   = FALSE,
   redcap_uri,
   token,
+  overwrite_with_blanks      = TRUE,
+  convert_logical_to_integer = FALSE,
   verbose             = TRUE,
   config_options      = NULL
 ) {
@@ -141,6 +154,8 @@ redcap_write <- function(
       ds               = ds_to_write[selected_indices, ],
       redcap_uri       = redcap_uri,
       token            = token,
+      overwrite_with_blanks = overwrite_with_blanks,
+      convert_logical_to_integer = convert_logical_to_integer,
       verbose          = verbose,
       config_options   = config_options
     )
@@ -157,7 +172,7 @@ redcap_write <- function(
     }
 
     affected_ids     <- c(affected_ids, write_result$affected_ids)
-    success_combined <- success_combined | write_result$success
+    success_combined <- success_combined & write_result$success
 
     rm(write_result) #Admittedly overkill defensiveness.
   }
