@@ -1,5 +1,5 @@
 #' @name retrieve_credential
-#' @aliases retrieve_credential_local retrieve_credential_mssql
+#' @aliases retrieve_credential_local retrieve_credential_mssql create_credential_local
 #' @title Read a token and other credentials from a (non-REDCap)
 #' database or file
 #'
@@ -14,6 +14,7 @@
 #'   check_username       = FALSE,
 #'   check_token_pattern  = TRUE
 #' )
+#'
 #' retrieve_credential_mssql(
 #'   project_id,
 #'   instance,
@@ -21,6 +22,10 @@
 #'   channel    = NULL
 #' )
 #'
+#' create_credential_local(
+#'   path_credential
+#' )
+#'
 #' @param path_credential The file path to the CSV containing the credentials.
 #'  Required.
 #' @param project_id The ID assigned to the project withing REDCap.  This
@@ -37,22 +42,45 @@
 #' Defaults to FALSE.
 #' @param check_token_pattern A `logical` value indicates if the token in the
 #' credential file is a 32-character hexadecimal string.  Defaults to FALSE.
-#' @param dsn A [DSN](http://en.wikipedia.org/wiki/Data_source_name) on the
+#' @param dsn A [DSN](https://en.wikipedia.org/wiki/Data_source_name) on the
 #' local machine that points to the desired MSSQL database. Required.
 #' @param channel An *optional* connection handle as returned by
 #' [DBI::dbConnect()].  See Details below. Optional.
 #'
-#' @return A list of the following elements:
+#' @return A list of the following elements are returned from
+#' `retrieve_credential_local()` and `retrieve_credential_mssql()`:
 #' * `redcap_uri`: The URI of the REDCap Server.
 #' * `username`: Username.
-#' * `project_id`: The ID assigned to the project withing REDCap.
+#' * `project_id`: The ID assigned to the project within REDCap.
 #' * `token`: The token to pass to the REDCap server
-#' * `comment`: An optional string.
+#' * `comment`: An optional string that is ignored by REDCapR
+#'   but can be helpful for humans.
 #'
 #' @details
 #' If the database elements are created with the script provided in package's
 #' 'Security Database' vignette, the default values will work.
 #'
+#' The `create_credential_local()` function copies a
+#' [static file](https://github.com/OuhscBbmc/REDCapR/blob/master/inst/misc/skeleton.credentials)
+#' to the location specified in the `path_credential` argument.
+#' Each record represents one accessible project per user.
+#' Follow these steps to adapt to your desired REDCap project(s):
+#' 1. Modify the credential file for the REDCap API with a text editor
+#'    like [Notepad++](https://notepad-plus-plus.org/),
+#'    [Visual Studio Code](https://code.visualstudio.com/), or
+#'    [nano](https://www.nano-editor.org/).
+#'    Replace existing records with the information from your projects.
+#'    Delete the remaining example records.
+#' 2. Make sure that the file (with the sensitive password-like) tokens
+#'    is stored securely!
+#' 3. Contact your REDCap admin to request the URI & token and
+#'    discuss institutional policies.
+#' 4. Ask your institution's IT security team for their recommendation
+#     securing the file.
+#' 5. For more info, see https://ouhscbbmc.github.io/REDCapR/articles/workflow-read.html
+#'    and https://ouhscbbmc.github.io/REDCapR/reference/retrieve_credential.html
+#' 6. Double-check the file is secured and not accessible by other users.
+#'
 #' @note
 #' Although we strongly encourage storing all the tokens on a central server
 #' (*e.g.*, see the `retrieve_credential_mssql()` function and the
@@ -68,7 +96,17 @@
 #' path <- system.file("misc/example.credentials", package = "REDCapR")
 #' (p1  <- REDCapR::retrieve_credential_local(path, 153L))
 #' (p2  <- REDCapR::retrieve_credential_local(path, 212L))
-
+#'
+#'
+#' \dontrun{
+#' # Create a skeleton of the local credential file to modify
+#' path_demo <- base::tempfile(pattern = "temp", fileext = ".credentials")
+#'
+#' create_credential_local(path_demo)
+#'
+#' base::unlink(path_demo) # This is just a demo; don't delete the real file!
+#' }
+#'
 #' @export
 retrieve_credential_local <- function(
   path_credential,
@@ -90,9 +128,10 @@ retrieve_credential_local <- function(
   )
 
   ds_credentials <- readr::read_csv(
-    file      = path_credential,
-    col_types = col_types,
-    comment   = "#"
+    file            = path_credential,
+    col_types       = col_types,
+    comment         = "#",
+    show_col_types  = FALSE
   )
 
   # Check that it's a data.frame with valid variable names
@@ -135,8 +174,30 @@ retrieve_credential_local <- function(
     )
   }
 
+  credential_local_validation(
+    redcap_uri              = credential$redcap_uri,
+    token                   = credential$token,
+    username                = credential$username,
+    check_url               = check_url,
+    check_username          = check_username,
+    check_token_pattern     = check_token_pattern
+  )
+
+  credential
+}
+
+# Privately-scoped function
+credential_local_validation <- function (
+  redcap_uri,
+  token,
+  username,
+  check_url                = TRUE,
+  check_username           = FALSE,
+  check_token_pattern      = TRUE
+
+) {
   # Progress through the optional checks
-  if (check_url & !grepl("https://", credential$redcap_uri, perl = TRUE)) {
+  if (check_url & !grepl("https://", redcap_uri, perl = TRUE)) {
     error_message_username <- paste(
       "The REDCap URL does not reference an https address.  First check",
       "that the URL is correct, and then consider using SSL to encrypt",
@@ -145,7 +206,7 @@ retrieve_credential_local <- function(
     )
     stop(error_message_username)
 
-  } else if (check_username & (Sys.info()["user"] != credential$username)) {
+  } else if (check_username & (Sys.info()["user"] != username)) {
     error_message_username <- paste(
       "The username (according to R's `Sys.info()['user']` doesn't match the",
       "username in the credentials file.  This is a friendly check, and",
@@ -155,7 +216,7 @@ retrieve_credential_local <- function(
     )
     stop(error_message_username)
 
-  } else if (check_token_pattern & !grepl("[A-F0-9]{32}", credential$token, perl = TRUE)) {
+  } else if (check_token_pattern & !grepl("[A-F0-9]{32}", token, perl = TRUE)) {
     error_message_token <- paste(
       "A REDCap token should be a string of 32 digits and uppercase",
       "characters.  The retrieved value was not.",
@@ -164,8 +225,40 @@ retrieve_credential_local <- function(
     )
     stop(error_message_token)
   }
+}
 
-  credential
+# system.file("misc/vignette.css", package="REDCapR")
+# system.file("misc/example.credentials", package="REDCapR")
+
+
+#' @export
+create_credential_local <- function (path_credential) {
+  path_source <- system.file(
+    "misc/example.credentials",
+    package   = "REDCapR"
+    # mustWork  = TRUE
+  )
+
+  if (!base::file.exists(path_source))
+    stop("The skeleton credential file was not found at `", path_source, "`.") # nocov
+
+  if (base::file.exists(path_credential))
+    stop("A credential file already exists at `", path_source, "`.")
+
+  if (!base::dir.exists(base::dirname(path_credential)))
+    base::dir.create(base::dirname(path_credential))
+
+  success <-
+    base::file.copy(
+      from        = path_source,
+      to          = path_credential,
+      overwrite   = FALSE
+    )
+
+  if (!success)
+    stop("The credential file could not be created at `", path_source, "`.") # nocov
+
+  success
 }
 
 #' @export
@@ -238,11 +331,12 @@ retrieve_credential_mssql <- function(
 
   base::tryCatch(
     expr = {
-      result        <- DBI::dbSendQuery(channel, sql)
-      DBI::dbBind(result, input)
-      d_credential  <- DBI::dbFetch(result)
+      d_credential  <- DBI::dbGetQuery(channel, sql, params = input)
+      # result        <- DBI::dbSendQuery(channel, sql)
+      # DBI::dbBind(result, input)
+      # d_credential  <- DBI::dbFetch(result, n = 1L)
     }, finally = {
-      if (!is.null(result))      DBI::dbClearResult(result)
+      # if (!is.null(result))      DBI::dbClearResult(result)
       if (close_channel_on_exit) DBI::dbDisconnect(channel)
     }
   )
