@@ -2,7 +2,7 @@ library(testthat)
 
 credential  <- retrieve_credential_testing()
 
-test_that("Smoke Test", {
+test_that("smoke", {
   testthat::skip_on_cran()
   expect_message(
     returned <- redcap_version(
@@ -12,7 +12,7 @@ test_that("Smoke Test", {
   )
 })
 
-test_that("Version Successful", {
+test_that("version-successful", {
   testthat::skip_on_cran()
   expect_message(
     actual <- redcap_version(
@@ -21,11 +21,11 @@ test_that("Version Successful", {
     )
   )
 
-  expected <- package_version("9.0.0")
+  expected <- package_version("10.5.1")
   expect_equal(actual, expected)
 })
 
-test_that("Version Unuccessful --bad token", {
+test_that("version-unuccessful-bad-token", {
   testthat::skip_on_cran()
   expect_message(
     actual <- redcap_version(
